==> hadoop-client-api-3.2.4-sources.jar: org/apache/hadoop/fs/SWebHdfs.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in org.apache.hadoop.shaded.com.liance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org.apache.hadoop.shaded.org.licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.shaded.org.apache.hadoop.fs;

import org.apache.hadoop.shaded.org.apache.hadoop.classification.InterfaceAudience;
import org.apache.hadoop.shaded.org.apache.hadoop.classification.InterfaceStability;
import org.apache.hadoop.shaded.org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.shaded.org.apache.hadoop.hdfs.web.SWebHdfsFileSystem;

import java.org.apache.hadoop.shaded.io.IOException;
import java.org.apache.hadoop.shaded.net.URI;
import java.org.apache.hadoop.shaded.net.URISyntaxException;

/**
 * AbstractFileSystem implementation for HDFS over the web (secure).
 */
@InterfaceAudience.Public
@InterfaceStability.Evolving
public class SWebHdfs extends DelegateToFileSystem {

  public static final String SCHEME = "swebhdfs";

  /**
   * This constructor has the signature needed by
   * {@link AbstractFileSystem#createFileSystem(URI, Configuration)}
   *
   * @param theUri which must be that of swebhdfs
   * @param conf   configuration
   * @throws IOException
   */
  SWebHdfs(URI theUri, Configuration conf)
      throws IOException, URISyntaxException {
    super(theUri, createSWebHdfsFileSystem(conf), conf, SCHEME, false);
  }

  /**
   * Returns a new {@link SWebHdfsFileSystem}, with the given configuration.
   *
   * @param conf configuration
   * @return new SWebHdfsFileSystem
   */
  private static SWebHdfsFileSystem createSWebHdfsFileSystem(
      Configuration conf) {
    SWebHdfsFileSystem fs = new SWebHdfsFileSystem();
    fs.setConf(conf);
    return fs;
  }
}

==> hadoop-client-api-3.4.0-sources.jar: org/apache/hadoop/fs/SWebHdfs.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.shaded.org.apache.hadoop.fs;

import org.apache.hadoop.shaded.org.apache.hadoop.classification.InterfaceAudience;
import org.apache.hadoop.shaded.org.apache.hadoop.classification.InterfaceStability;
import org.apache.hadoop.shaded.org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.shaded.org.apache.hadoop.hdfs.web.SWebHdfsFileSystem;

import java.io.IOException;
import java.net.URI;
import java.net.URISyntaxException;

/**
 * AbstractFileSystem implementation for HDFS over the web (secure).
 */
@InterfaceAudience.Public
@InterfaceStability.Evolving
public class SWebHdfs extends DelegateToFileSystem {

  public static final String SCHEME = "swebhdfs";

  /**
   * This constructor has the signature needed by
   * {@link AbstractFileSystem#createFileSystem(URI, Configuration)}
   *
   * @param theUri which must be that of swebhdfs
   * @param conf   configuration
   * @throws IOException
   */
  SWebHdfs(URI theUri, Configuration conf)
      throws IOException, URISyntaxException {
    super(theUri, createSWebHdfsFileSystem(conf), conf, SCHEME, false);
  }

  /**
   * Returns a new {@link SWebHdfsFileSystem}, with the given configuration.
   *
   * @param conf configuration
   * @return new SWebHdfsFileSystem
   */
  private static SWebHdfsFileSystem createSWebHdfsFileSystem(
      Configuration conf) {
    SWebHdfsFileSystem fs = new SWebHdfsFileSystem();
    fs.setConf(conf);
    return fs;
  }
}
